dslinux/linux-2.6.x/include/asm-arm/arch-nds gbarom-macro.S

amadeus dslinux_amadeus at user.in-berlin.de
Sun Sep 10 21:13:59 CEST 2006


Update of /cvsroot/dslinux/dslinux/linux-2.6.x/include/asm-arm/arch-nds
In directory antilope:/tmp/cvs-serv32515/linux-2.6.x/include/asm-arm/arch-nds

Modified Files:
	gbarom-macro.S 
Log Message:
Improve M3 switching

Index: gbarom-macro.S
===================================================================
RCS file: /cvsroot/dslinux/dslinux/linux-2.6.x/include/asm-arm/arch-nds/gbarom-macro.S,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -d -r1.4 -r1.5
--- gbarom-macro.S	3 Sep 2006 20:23:46 -0000	1.4
+++ gbarom-macro.S	10 Sep 2006 19:13:57 -0000	1.5
@@ -154,7 +154,7 @@
 	ldrh	ip, [r3]
 	ldr	r3, =0x08801b66
 	ldrh	ip, [r3]
-	ldr	r3, =0x08800006
+	ldr	r3, =0x08800006	@ mode MEDIA
 	ldrh	ip, [r3]
 	ldr	r3, =0x0800080e
 	ldrh	ip, [r3]
@@ -163,11 +163,12 @@
 	ldr	r3, =0x09000000
 	ldrh	ip, [r3]
 	.endm
+
 /* 
  * m3_set_rom: M3SD/CF is set to ROM mode.
  * Use only register R3 and IP.
  */
-	.macro	m3_set_rom
+	.macro	m3_set_ram
 	ldr	r3, =0x08e00002
 	ldrh	ip, [r3]
 	ldr	r3, =0x0800000e
@@ -182,30 +183,14 @@
 	ldrh	ip, [r3]
 	ldr	r3, =0x08801b66
 	ldrh	ip, [r3]
-	ldr	r3, =0x08800008
+	ldr	r3, =0x0880000C	@ mode RAM (RW)
 	ldrh	ip, [r3]
 	ldr	r3, =0x0800080e
 	ldrh	ip, [r3]
 	ldr	r3, =0x08000000
 	ldrh	ip, [r3]
-	ldr	r3, =0x080001e4
-	ldrh	ip, [r3]
-	ldrh	ip, [r3]
-	ldr	r3, =0x08000188
-	ldrh	ip, [r3]
+	ldr	r3, =0x09000000
 	ldrh	ip, [r3]
 	.endm
-/* 
- * m3_set_rw: if the previous mode of M3SD/CF was "ROM",
- * allow write access. Use only register R2, R3 and IP.
- */
-	.macro	m3_set_rw
-	ldr	r3, =0x09FFEFFE
-	ldr	ip, =0xAA55
-	ldrh	r2, [r3]	@ read old value @ 0x09FFEFFE
-	strh	ip, [r3]
-	strh	ip, [r3]
-	strh	r2, [r3]	@ restore old value
-	.endm
 
 /*****************************************************************************/
@@ -163,11 +163,12 @@
 /* 
- * m3_set_rom: M3SD/CF is set to ROM mode.
+ * m3_set_ram: M3SD/CF is set to RAM mode.
  * Use only register R3 and IP.
  */




More information about the dslinux-commit mailing list